<?php

namespace Hrms\Hrm\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Hrms\Hrm\Http\Requests\DepartmentManagmentUserRequest;
use Hrms\Hrm\Interfaces\DepartmentManagmentRepositoryInterface;
use Response;
use User;

class DepartmentManagmentUserController extends UserController
{
    /**
     * Initialize department_managment controller.
     *
     * @param type DepartmentManagmentRepositoryInterface $department_managment
     *
     * @return type
     */
    public function __construct(DepartmentManagmentRepositoryInterface $department_managment)
    {
        $this->model = $department_managment;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(DepartmentManagmentUserRequest $request)
    {
        $department_managments = $this->model->all();

        $this->theme->prependTitle(trans('hrm::department_managment.names').' :: ');

        return $this->theme->of('hrm::user.department_managment.index', compact('department_managments'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(DepartmentManagmentUserRequest $request, $role, $id)
    {
        $department_managment = $this->model->find($id);

        return $this->theme->of('hrm::user.department_managment.show', compact('department_managment'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DepartmentManagmentUserRequest $request)
    {
        $department_managment = $this->model->findOrNew(0);

        Former::populate($department_managment);

        return $this->theme->of('hrm::user.department_managment.create', compact('department_managment'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DepartmentManagmentUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $department_managment = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('hrm::department_managment.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(DepartmentManagmentUserRequest $request, $role, $id)
    {
        $department_managment = $this->model->find($id);

        Former::populate($department_managment);

        return $this->theme->of('hrm::user.department_managment.edit', compact('department_managment'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(DepartmentManagmentUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $department_managment = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('hrm::department_managment.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(DepartmentManagmentUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('hrm::department_managment.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
